#
# spec file for package kube-no-trouble
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kube-no-trouble
Version:        0.7.0
Release:        1.5
Summary:        Easily check your cluster for use of deprecated APIs
License:        MIT
URL:            https://github.com/doitintl/kube-no-trouble
Source:         kube-no-trouble-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.16

%description
Easily check your cluster for use of deprecated APIs

Kubernetes 1.16 is slowly starting to roll out, not only across various managed Kubernetes offerings, and with that come a lot of API deprecations1.

Kube No Trouble (kubent) is a simple tool to check whether you're using any of these API versions in your cluster and therefore should upgrade your workloads first, before upgrading your Kubernetes cluster.

This tool will be able to detect deprecated APIs depending on how you deploy your resources, as we need the original manifest to be stored somewhere. In particular following tools are supported:
* file - local manifests in YAML or JSON
* kubectl - uses the kubectl.kubernetes.io/last-applied-configuration annotation
* Helm v2 - uses Tiller manifests stored in K8s Secrets or ConfigMaps
* Helm v3 - uses Helm manifests stored as Secrets or ConfigMaps directly in individual namespaces

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -ldflags="-X main.Version=%{version}" \
   -o bin/kubent ./cmd/kubent/main.go

%install
# Install the binary.
install -D -m 0755 bin/kubent "%{buildroot}/%{_bindir}/kubent"

%files
%doc README.md
%license LICENSE
%{_bindir}/kubent

%changelog
* Fri Dec 16 2022 kastl@b1-systems.de
- Update to version 0.7.0:
  * dep: Go Bump github.com/rs/zerolog from 1.26.1 to 1.28.0
  * dep: Go Bump k8s.io/client-go from 0.25.4 to 0.26.0
  * dep: Go Bump github.com/open-policy-agent/opa from 0.47.1 to 0.47.2
  * fix: Remove duplicated lines from pre-commit
  * dep: Go bump github.com/hashicorp/go-version from 1.3.0 to 1.6.0
  * ci: Closes stale issues and stale prs
  * dep: Docker Bump golang from 1.19.3-alpine3.16 to 1.19.4-alpine3.16
  * dep: Go Bump github.com/open-policy-agent/opa from 0.46.1 to 0.47.1
  * feat: Disable any logging from go-client's klog
  * ci: Upgrade integration test versions to 1.19-1.25
  * dep: Go Bump github.com/open-policy-agent/opa from 0.34.2 to 0.46.1
  * docs: Fix missing newline in changelog w. breaking changes
  * test: Fix tests after upgrading go-client
  * docs: Remove Helm v2 references
  * dep: Update client-go and apimachinery to v0.25.4 and helm to v3.10.2
  * feat: Remove Helm v2 support
  * build: Install bash so build script can run in alpine
  * build: Fix shell selection for Makefile
  * ci: Fix latest tag issue in nightly builds
  * dep: Docker Bump golang from 1.19.2-alpine3.16 to 1.19.3-alpine3.16
  * fix: Ignore empty documents from Helm collectors
  * chore: Add debug-level logging to Helm collectors
* Mon Oct 10 2022 kastl@b1-systems.de
- Update to version 0.6.0:
  * ci: Fix latest tag and avoid rebuild
  * dep: Docker bump golang from 1.19.1-alpine3.16 to 1.19.2-alpine3.16
  * ci: Fix missing build info in docker images
  * ci: Fix missing build info in docker images
  * docs: Add Docker section to readme
  * docs: Improve release note formatting
  * fix: Full path of the docker registry and path to docker image
  * feat: Cover deprecated autoscaling/v2beta1 and autoscaling/v2beta2 PI group - HPA
  * fix: Name of repo now correctly expanded when pushing to docker registry
  * ci: Notify users of the aarch64 option when installing
  * fix: Helm - only default to release namespace for namespaced resources
  * ci: Build and publish docker image
  * fix: Collect Ingress via v1 API
  * docs: Update help output in readme to include -O flag
  * test: Add tests for -O flag
  * feat: Add -O flag to configure output to file
  * test: Refactor Main tests to pass arguments directly
  * feat: Add OutputFile option to config
  * test: Add tests for text printer
  * feat: Add output file support to text printer
  * test: Add tests for JSON printer
  * feat: Add output file support to JSON printer
  * feat: Add outputFile support to Printer/commonPrinter
  * test: Ref TestParsePrinter to test the resp. function
  * feat: Support for checking additional annotations
  * dep: Docker bump golang from 1.19.0-alpine3.16 to 1.19.1-alpine3.16
  * ci: Pre-commit to catch new spelling issues
  * chore: Spelling fixes
  * chore: Users can install latest nightly
  * chore: Test empty output text/json, ensuring json returns empty array and text stdout is empty when no issues are found
  * test: Reduce test noise level
  * test: Add tests for snapshot.storage.k8s.io/v1beta1
  * feat: Add support for detecting snapshot.storage.k8s.io/v1beta1
  * feat: User agent and dryup tests
  * docs: Add example of scanning all files in a directory
  * build: Update to golang 19, go mod tidy too
  * docs: Update link to blog
  * ci: Update checkout action to lastest
  * fix: Arch detection dectection for aarch64
  * feat: Version flag
  * chore: Pre-commit fixed versions and remove broken make linter
  * fix: Resource name can be undefined in some cases
  * test: Fix review* fixture manifests to contain metadata
  * test: Fix rules tests to actually evaluate
  * ci: Update checkout to v2
  * fix: Fix CronJob rego
  * dep: Go bump github.com/open-policy-agent/opa from 0.33.1 to 0.34.2
  * fix: Fix unpopulated discovery client and add test for same
  * feat: Add support for in-cluster auth
  * test: Refactor out env variable setup
  * test: Extract hardcoded fixtures path to const
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.5.1:
  * This release fixes a few issues, most notably broken MacOS ARM binary (#220) and broken additional kind (-a) functionality (#209).
  * Fixes:
  - Fix additional filter (209 by stepanstipl)
  - Fix since output format (225 by stepanstipl)
  - Fix broken MacOS binary (via 220 by david-doit-intl)
  * Internal/Other:
  - Remove upx (220 by david-doit-intl)
  - dep: Go bump github.com/open-policy-agent/opa from 0.28.0 to 0.31.0 (199 by dependabot)
  - dep: Go bump github.com/open-policy-agent/opa from 0.31.0 to 0.33.1 (222 by dependabot)
  - dep: Golang 1.17 (219 by david-doit-intl)
  - docs: Add logos (203 by stepanstipl)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.5.0:
  * The main theme of this release is increased coverage - namely resources that will be removed in Kubernetes versions 1.22 and 1.25 (#156, #159, #160, #163, #165, #166, #168, #169, #170, #171, #172, #173, #174, #175).
  * We also worked on making the tool more user friendly and useable out of the box:
  - Detecting K8s version (#139) and display only relevant results (#182)
  - Support for multiple kubeconfig files (#191) and selecting K8S context (#194)
  - Building ARM binaries for Linux and Mac (#133)
  * Fixed a few bugs too, and increased test coverage, sped up build process. And bIg clap to @david-doit-intl for laying out foundations for integration testing (#152).
* Wed May 26 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of package kube-no-trouble
